Add topo_clip.pyw wrapper v0.0.2
Edit setup.py

file:ecfc609c49df6a69583254456ed95a694820b7b7 -> file:3cbf685b1a5dc58e3b02a5e1cb15049cc1437d91
--- /dev/null
+++ b/topo_clip.pyw
@@ -0,0 +1,31 @@
+#!/usr/bin/python2.5
+
+# Wrapper to launch topo_clip
+# Simeon Veldstra 29 Jan 2008
+
+
+# Clip data from a CSV file if it is inside a polygon
+# Simeon Veldstra 22 Jan 2008
+#
+# Copyright (C) 2008 Simeon Veldstra
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software Foundation,
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
+
+
+from geomorph.topo_clip import main
+
+import sys
+
+if __name__ == '__main__':
+ main(sys.argv)
--- a/setup.py
+++ b/setup.py
@@ -1,9 +1,13 @@
# topo_clip distutils setup script
from distutils.core import setup
-setup(name="topo_clip",
- version="0.0.1",
- py_modules=['pip', 'mainwindow'],
+setup(name="geomorph",
+ version="0.0.2",
+ author="Simeon Veldstra",
+ author_email="reallifesim@gmail.com",
+ url="http://puddle.ca/geomorph/",
+ description="Software for people who move the earth",
+ packages=['geomorph', 'geomorph/ui'],
scripts=['topo_clip.pyw'],
windows=[{"script": "topo_clip.pyw"}] )
file:03619b6dbe08dc7857a5a462c948961c3ff85b22(new)
@@ -1,9 +1,13 @@
-# topo_clip distutils setup script
+# geomorph distutils setup script
from distutils.core import setup